import { useEffect, useState } from 'react';
import PropTypes from 'prop-types';
import LazyContent from './lazyContent.js';
import './index.scss';
import { jsx as _jsx } from "react/jsx-runtime";
var BOTS_USER_AGENTS = ['googlebot', 'google-structured-data-testing-tool', 'bingbot', 'linkedinbot', 'mediapartners-google', 'debugbear'];
function checkUserAgentIsBot(userAgent, botsUserAgents) {
  var lowerCaseUserAgent = userAgent.toLowerCase();
  // check if the userAgent is a bot
  return botsUserAgents.some(function (ua) {
    return lowerCaseUserAgent.includes(ua);
  });
}
export default function PerfDynamicRendering(_ref) {
  var _ref$botsUserAgents = _ref.botsUserAgents,
    botsUserAgents = _ref$botsUserAgents === void 0 ? BOTS_USER_AGENTS : _ref$botsUserAgents,
    children = _ref.children,
    disabled = _ref.disabled,
    forceRender = _ref.forceRender,
    _ref$height = _ref.height,
    height = _ref$height === void 0 ? 0 : _ref$height,
    placeholder = _ref.placeholder,
    rootMargin = _ref.rootMargin,
    userAgent = _ref.userAgent;
  var isBot = checkUserAgentIsBot(userAgent, botsUserAgents);
  var _useState = useState(false),
    isOnBrowser = _useState[0],
    setIsOnBrowser = _useState[1];
  useEffect(function () {
    setIsOnBrowser(true);
  }, []);

  // Force render in server and client
  if (forceRender) return children;

  // if isBot or disabled, we return in server and client the content
  if (isBot) return children;

  // now, we're sure the user isNotBot
  // so check if we're on the browser side and if is not disabled the component
  if (isOnBrowser && !disabled) {
    return /*#__PURE__*/_jsx(LazyContent, {
      rootMargin: rootMargin,
      placeholder: placeholder,
      height: height,
      children: children
    });
  } else if (placeholder) {
    // so, we're on the server side or the component is disabled
    return placeholder;
  } else {
    return /*#__PURE__*/_jsx("div", {
      style: {
        containIntrinsicSize: "auto " + height + "px",
        height: height + "px",
        marginBottom: '1px'
      }
    });
  }
}
PerfDynamicRendering.displayName = 'PerfDynamicRendering';